@@ -68,9 +68,11 @@
 #'
 #' @return
 #' A list
-#'
+#' @name ts_auto_arima_xgboost
+NULL
+
 #' @export
-#'
+#' @rdname ts_auto_arima_xgboost
 
 ts_auto_arima_xgboost <- function(.data, .date_col, .value_col, .formula, .rsamp_obj,
                                   .prefix = "ts_arima_boost", .tune = TRUE, .grid_size = 10,
